==> content_insights_report-1.0.8.tar.gz: content_insights_report/README.md <==
# Content Insights Report

This module generates a Content Insights Report that provides valuable data and
analysis about the content in your system. The report is based on various
parameters, including content type, status, and workflows, giving you insights
into the overall performance and status of the content within your system.


For a full description of the module on drupal.org, visit the
[project page](https://www.drupal.org/project/content_insights_report).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/search/content_insights_report).

## Table of contents

- Requirements
- Installation
- Configuration
- Troubleshooting & FAQ
- Maintainers
- Changelog

## Requirements

This module requires the following core modules:

- **node** Report is based on node content data.
- **content_moderation** Not required, but if module is enabled the data will
pull thru if settings is enabled for Moderation state.

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).
```bash
composer require drupal/content_insights_report
```

## Configuration

**Configuration:**

Navigate to Configuration > Content authoring > Content Insights Report using
the Admin Toolbar.

Alternatively, you can also use this link:
/admin/config/content/content_insights_report/settings

**Report:**

Navigate to Reports > Content Insights Report using the Admin Toolbar.

Alternatively, you can also use this link:
/admin/reports/content-insights-report

## Troubleshooting & FAQ

Q: Why can't I see the report?

A: It might be related to permissions.
Please follow the /admin/people/permissions/module/content_insights_report
to check the permissions.

## Maintainers

Current maintainers:

- [Kobus van Wyk (kobusvw)](https://www.drupal.org/u/kobusvw)

## Changelog

- **2025/03/09** - Add Total number of nodes, published and unpublished
- **2025/03/09** - Add Show/Hide on empty results (if no results are found, remove section from the report)
- **2025/03/09** - Change link to content to custom content page, Page will include date filters (created, changed & revision) Only Edit button will be available.
- **2025/03/09** - Add revision count to report
- **2025/03/09** - Change yes/no config fields to checkbox
- **2025/03/09** - Update styling of both reports.

==> content_insights_report-1.0.9.tar.gz: content_insights_report/README.md <==
# Content Insights Report

This module generates a Content Insights Report that provides valuable data and
analysis about the content in your system. The report is based on various
parameters, including content type, status, and workflows, giving you insights
into the overall performance and status of the content within your system.

The module includes two versions:
- Standard report for site-wide content analysis
- Group-specific report for analyzing content within Drupal groups

For a full description of the module on drupal.org, visit the
[project page](https://www.drupal.org/project/content_insights_report).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/search/content_insights_report).

## Table of contents

- Requirements
- Installation
- Configuration
- Troubleshooting & FAQ
- Maintainers
- Changelog

## Requirements

This module requires the following core modules:

- **node** Report is based on node content data.
- **content_moderation** Not required, but if module is enabled the data will
pull thru if settings is enabled for Moderation state.
- **group** Required for the group-specific report functionality.

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).
```bash
composer require drupal/content_insights_report
```

## Configuration

**Configuration:**

Navigate to Configuration > Content authoring > Content Insights Report using
the Admin Toolbar.

Alternatively, you can also use this link:
/admin/config/content/content_insights_report/settings

Available settings:
- Show/Hide summary section
- Show/Hide insights report
- Show/Hide workflow moderation state report
- Show/Hide created by and date information
- Show/Hide empty results
- Number of months to display in insights
- Percentage calculation basis (all nodes, published nodes, unpublished nodes)
- Sort options
- Print functionality

**Reports:**

1. Site-wide Report:
   - Navigate to Reports > Content Insights Report
   - URL: /admin/reports/content-insights-report

2. Group-specific Report:
   - Access through group pages
   - Requires group membership and appropriate permissions

## Troubleshooting & FAQ

Q: Why can't I see the report?

A: It might be related to permissions.
Please follow the /admin/people/permissions/module/content_insights_report
to check the permissions.

Q: Why can't I see the group report?

A: Ensure you have:
1. The group module installed and configured
2. Appropriate group permissions
3. Group membership with report access rights

## Maintainers

Current maintainers:

- [Kobus van Wyk (kobusvw)](https://www.drupal.org/u/kobusvw)

## Changelog

- **2025/03/09** - Add Total number of nodes, published and unpublished
- **2025/03/09** - Add Show/Hide on empty results (if no results are found, 
remove section from the report)
- **2025/03/09** - Change link to content to custom content page, Page will 
include date filters (created, changed & revision) Only Edit button will be 
available.
- **2025/03/09** - Add revision count to report
- **2025/03/09** - Change yes/no config fields to checkbox
- **2025/03/09** - Update styling of both reports.
